@@ -1,20 +1,23 @@
-use strict;
-use warnings;
+# NAME: CAD-OpenSCAD
+# ABSTRACT: Module to generate OpenSCAD files using Perl
+
+use strict; use warnings;
+
 use Object::Pad;
 use CAD::OpenSCAD::Math;
 
-our $Math=new Math;
+our $Math=new CAD::OpenSCAD::Math;
 
-our $VERSION='0.11';
+our $VERSION='0.12';
 
 =head1 NAME
 
-CAD::OpenSCAD  Module to generate .scad file from Perl
+CAD::OpenSCAD  
 
-=head1 SYNOPSIS
+=head2 SYNOPSIS
 
      use CAD::OpenSCAD;
-     my $scad=new SCAD;
+     my $scad=new OpenSCAD;
      $scad->cube("main",[10,10,10],1)
           ->cylinder("hole",{r=>4,h=>20},1)
           ->difference("newObject","main","hole")
@@ -22,32 +25,32 @@ CAD::OpenSCAD  Module to generate .scad file from Perl
           ->save("testScad");
 
 
-=head1 DESCRIPTION
+=head2 DESCRIPTION
 
-This module allows creation of SCAD scripts for running through OpenSCAD,
+This module allows creation of OpenSCAD scripts for running through OpenSCAD,
 the "Programmers CAD Application". OpenSCAD can be scripted, having a
 fairly comprehensive language to create complex 3D objects.
 CAD::OpenSCAD allows generation and manipulation of 3D objects in a
 Perlish way,while relying on OpenSCAD to do all the hardwork, merely by
 generating SCAD scripts.
 
-=head1 MAIN METHODS
+=head2 MAIN METHODS
 
-Creating a SCAD object is by the standard methods.
+Creating an  OpenSCAD object is by the standard methods.
 Optional parameters are hash C<< key=>value >> pairs.
 valid keys are C<fa>, C<fs> and C<tab>
 
      use CAD::OpenSCAD;
-     my $scad=new SCAD();
+     my $scad=new OpenSCAD();
      # optionally can add fs, fa and tab on intialisation
-     # e.g my $scad=new SCAD(fs=>1, fa=>0.4, tab=>0);
+     # e.g my $scad=new OpenSCAD(fs=>1, fa=>0.4, tab=>0);
 
-New elements can be added to this SCAD object; each object is named
+New elements can be added to this OpenSCAD object; each object is named
 for subsequent transformations
 =cut
 
 
-class SCAD{
+class OpenSCAD{
    field $script :reader :param  //="";
    field $items  :reader :writer //={};
    field $fa     :writer :reader :param //=1;
@@ -64,16 +67,16 @@ class SCAD{
    field $status :writer;
    field $extensions  ={};
 
-=head3 set_fs set_fa set_tab
+=head4 set_fs set_fa set_tab
 
 Using these, one can set parameters for the surface generation and script
 outputs. e.g.
 
   $scad->set_fa(10) 
 
-=head2 3D Primitive Shapes
+=head3 3D Primitive Shapes
 
-=head3 cube
+=head4 cube
 
 C<cube> creates a cube element e.g.
 
@@ -92,7 +95,7 @@ element is centered in the origin (a true value here centers the element)
       return $self;
    }
    
-=head3 cylinder
+=head4 cylinder
 
 Creates a cylinder element e.g.
 
@@ -110,7 +113,7 @@ the element is centered on the origin (a true value here centers the element)
       return $self;
   }
 
-=head3 sphere
+=head4 sphere
 
 Creates a sphere element e.g.
 
@@ -136,9 +139,9 @@ of defining radius of the sphere.
 
 
 
-=head2 Transformations
+=head3 Transformations
 
-=head3 translate
+=head4 translate
 
 Moves an element by name a specified displacement in X,Y,Z directions
 e.g. 
@@ -157,7 +160,7 @@ The second parameter is an arrayref of three elements defining displacement.
 	  
   }
 
-=head3 rotate
+=head4 rotate
 
 Rotates an element by name around X,Y,Z axes about the origin [0,0,0].e.g.
 
@@ -176,7 +179,7 @@ in degrees.
 	  
   }
   
-=head3 mirror
+=head4 mirror
 
 Mirrors an element by name about a plane. That plane is defined by the normal to that vector, 
 and the plane goes through the origin.
@@ -196,7 +199,7 @@ is an arrayref containg the planes normal e.g.[1,0,0] implies a mirroring about
 	  
   }
     
-=head3 resize
+=head4 resize
 
 Resizes an element by name to specified dimensions in X,Y,Z directions.e.g.
 
@@ -214,7 +217,7 @@ scale factors.
 	  
   }
   
-=head3 scale
+=head4 scale
 
 Scales an element by name by specified ratios in X,Y,Z directions.e.g.
 
@@ -231,7 +234,7 @@ The second parameter is an arrayref of three scale factors.
 	  
   } 
 
-=head3 multimatrix
+=head4 multimatrix
 
 Multiplies the geometry of all child elements with the given
 L<affine|https://en.wikipedia.org/wiki/Transformation_matrix#Affine_transformations>
@@ -246,7 +249,7 @@ with the 4th row always forced to [0,0,0,1].
 	  
   } 
 
-=head3 skew
+=head4 skew
 
 Uses MultiMatrix to transform a item by skewing in xy, yx, zy, yz, xz, zx  planes.
 this uses a matrix described in L<this gist|https://gist.github.com/boredzo/fde487c724a40a26fa9c>
@@ -275,7 +278,7 @@ this uses a matrix described in L<this gist|https://gist.github.com/boredzo/fde4
 
 
 
-=head3 offset
+=head4 offset
 
 Offset generates a new 2d interior or exterior outline from an existing outline.
 There are two modes of operation: radial and delta.
@@ -288,11 +291,11 @@ There are two modes of operation: radial and delta.
 	  
   } 
 
-=head3 hull
+=head4 hull
 
 Displays the convex hull of child nodes.
 
-	my $chart=new SCAD;
+	my $chart=new OpenSCAD;
 	my $pos=[0,0,0]; my @cubes=(); my @hulls=();
 	for (0..100){   # a hundred randomly displaced cubes
 		$chart->cube("dot$_",3)->translate("dot$_",$pos);
@@ -316,7 +319,7 @@ Displays the convex hull of child nodes.
 	  
   }   
 
-=head3 minkowski
+=head4 minkowski
 
 =cut
   
@@ -328,9 +331,9 @@ Displays the convex hull of child nodes.
   }   
   
   
-=head2 Boolean Operations
+=head3 Boolean Operations
 
-=head3  union
+=head4  union
 
 Implicitly joins multiple elements into one element.e.g.C<< $scad->union("wheel",qw/wheel nut nut1 nut2 nut3/); >>
 the first item is the name of the new element created, the following elements are elements to be joined together.
@@ -347,7 +350,7 @@ If an element with the name of the first parameter does not exist, it is created
   }
 
 
-=head3 difference
+=head4 difference
 
 Subtracts one or more elements from one element and creates a new element.
 e.g.
@@ -370,7 +373,7 @@ in "wheel" (first parameter).
       return $self;
   }  
   
-=head3 intersection
+=head4 intersection
 
 Creates an element representing the overlapping parts of 2 or more elements
 .e.g.
@@ -390,9 +393,9 @@ elements which overlap neach other.
       return $self;
   }  
 
-=head2 2D Primitive Shapes
+=head3 2D Primitive Shapes
 
-=head3 circle
+=head4 circle
 
 A 2D drawing primitive that creates a circle that may be extruded to create other 3D structures.
 e.g
@@ -406,7 +409,7 @@ e.g
       return $self;
   }
   
-=head3 square
+=head4 square
 
 a 2D drawing primitive that creates a rectangle that may be extruded to create other 3D structures.
 e.g 
@@ -421,12 +424,12 @@ $scad->square("square",[10,10]);
       return $self;
   }
 
-=head3 polygon
+=head4 polygon
 
 A 2D drawing primitive that creates a polygon that may be extruded to create other 3D structures .
 Example:- 
 
-  my $extrusion=new SCAD;
+  my $extrusion=new OpenSCAD;
   $extrusion->variable({p0=>[0, 0],p1 => [0, -30],p2 => [15, 30],p3=> [35, 20],p4 => [35, 0]})
             ->variable("points",[qw/p0 p1 p2 p3 p4 /] )
             ->polygon("poly","points")
@@ -440,7 +443,7 @@ Example:-
       return $self;
   }
 
-=head3 text
+=head4 text
 
 Allows 2D text shapes to be created, that may be extruded and manipulated like other items
 e.g. 
@@ -469,13 +472,13 @@ to just use defaults.
   }
 
 
-=head2 Extrusion
+=head3 Extrusion
 
-=head3 rotate_extrude
+=head4 rotate_extrude
 
 A method to extrude a 2D shape while rotating invokes similar to liner_extrude
 
-  my $extrusion=new SCAD;
+  my $extrusion=new OpenSCAD;
   $extrusion->circle("circle",{r=>5})
             ->translate("circle",[10,0,0])
             ->rotate_extrude("circle",{angle=>180});
@@ -488,7 +491,7 @@ A method to extrude a 2D shape while rotating invokes similar to liner_extrude
       return $self;
   }  
 
-=head3 liner_extrude
+=head4 liner_extrude
 
 A method to extrude a 2D shape see above for example
 =cut
@@ -500,7 +503,7 @@ A method to extrude a 2D shape see above for example
   }  
 
 
-=head3 color
+=head4 color
 
 colors an item e.g. . 
 
@@ -524,7 +527,7 @@ colors an item e.g. .
 	  $scr=$tabs.(join "\n$tabs", (split "\n",$scr))."\n";
 	  return $scr;
   }
-=head3 clone
+=head4 clone
 
 Creates copies of elements with same features. e.g.
 
@@ -569,7 +572,7 @@ This just copies the code for the element into new elements, for subsequent tran
     
 
     
-=head3 variable
+=head4 variable
 
 Creates variables that SCAD can use for customising objects easily 
 (see polygon example above)
@@ -611,9 +614,9 @@ Creates variables that SCAD can use for customising objects easily
       return $dims;
   }
   
-=head2 Build and Save
+=head3 Build and Save
   
-=head3 build
+=head4 build
 
 Collects the elements specified (i.e. not all the elements, just the items required for the build)
 and all the variables to generate a scad file.  The scad file generated include all the variables defined,
@@ -645,7 +648,7 @@ the modules built and the libraries used
 	  }
 	  return $self;
   }
-=head3 save
+=head4 save
 
 saves the .scad file, and also uses openscad to generate images or 3D objects
 from the script, or open it in openSCAD directly after building the shape;
@@ -732,19 +735,20 @@ e.g. C<< $scad->save("extrusion","png") >>
 }
 
 
-class Item{
-   field $name     :reader :param  ;
-   field $description     :reader :param  //="";
-   field $script   :reader :param  //="";
-   field $insPoint :reader :writer :param //=[0,0];
-   field $rotation :reader :writer :param //=[0,0,0];
+class scadItem{
+   field $name            :reader :param  ;
+   field $description     :reader :writer :param  //="";
+   field $script          :reader :param  //="";
+   field $insPoint        :reader :writer :param //=[0,0];
+   field $rotation        :reader :writer :param //=[0,0,0];
    field $vertices  = [];
    field $faces  = [];
 }
 
-=head1 SUPPORT
+=head2 SUPPORT
+
+=head2 COPYRIGHT AND DISCLAIMERS
 
-=head1 COPYRIGHT AND DISCLAIMERS
 Copyright (c) 2025 Saif Ahmed.
 
 This library is free software; you can redistribute it and/or
@@ -755,9 +759,11 @@ but without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 
-=head1 AUTHOR
+=head2 AUTHOR
+
 SAIFTYNET
 
-=head1 CONTRIBUTORS
+=head2 CONTRIBUTORS
+
 jmlynesjr
 =cut
